Rucio Package
=============


Development takes place via the usual Rucio processes as outlined in `<http://rucio.cern.ch/>`_.

The master repository is on `<https://gitlab.cern.ch/rucio01/rucio>`_.

See release notes and more at `<https://its.cern.ch/jira/browse/RUCIO>`_.
